# Name: libsetuproi/app.py
# Purpose: setuproi's main() function and wxPython Application
# Author: Ken McIvor <mcivor@iit.edu>
#
# Copyright 2006 Illinois Institute of Technology
#
# See the file "LICENSE" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.

import wx
import sys
import optparse
import libsetuproi
from libsetuproi.wxview import *
from libsetuproi.director import *
from libsetuproi.roiview import *


def fatal_error(msg):
    sys.stderr.write('Error: ')
    sys.stderr.write(str(msg))
    sys.stderr.write('\n')
    sys.exit(1)


def fatal_io_error(err):
    if issubclass(err.__class__, IOError) and err.strerror and err.filename:
        err = '%s: %s' % (err.strerror, err.filename)
    fatalError(err)


def parse_arguments(args):
    USAGE = '%prog [OPTIONS...]'
    VERSION = ('%prog ' + libsetuproi.__version__
        + ', by Ken McIvor <mcivor@iit.edu>')
    parser = optparse.OptionParser(usage=USAGE, version=VERSION)

    opts, args = parser.parse_args(args)
    if len(args) != 0:
        parser.print_usage()
        sys.exit(1)

    return opts, args


class AppNullView(NullView):
    windowName = dialogName = 'setuproi'


class SetupRoiApplication(wx.PySimpleApp):
    def __init__(self):
        self.director = AppDirector(AppNullView(), SetupRoiFrame)
#        self.director = AppDirector(AppNullView(), TestFrame)
        wx.PySimpleApp.__init__(self)

    def OnInit(self):
        self.director.createNewFrame()
        return True


class TestFrame(FrameView):
    windowName = 'setuproi'

    def __init__(self, parent, director, **kwds):
        wx.Frame.__init__(self, parent, -1, '', **kwds)
        self.director = director
        self.updateTitle('fileName')

        wx.EVT_CLOSE(self, self.OnClose)

    def OnClose(self, evt):
        if self.director.canClose():
            evt.Skip()

    def canClose(self):
        return False


def main(argv):
    opts, args = parse_arguments(argv)
    app = SetupRoiApplication()
    app.MainLoop()
