# Name: libsetuproi/spectra.py
# Purpose: Class to hold channels of spectra
# Author: Ken McIvor <mcivor@iit.edu>
#
# Copyright 2006 Illinois Institute of Technology
#
# See the file "LICENSE" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.

import xdp.io

__all__ = ['Spectra']


class Spectra:
    """
    Channels of spectra loaded from a file.

    @type fileName: string
    @var  fileName: this spectra's file

    @type channels: tuple
    @var  channels: spectrum data of each channel
    """

    def __init__(self, fileName, matrix):
        """
        Create a Spectra representing the data set I{matrix} loaded from
        I{fileName}.
        """
        self.fileName = fileName

        if matrix is None:
            self.channels = ()
        else:
            self.channels = tuple(
                [matrix[:,i] for i in range(matrix.shape[1])])

    def fromFile(cls, fileName):
        """
        Create a new Spectra from the columns of data set stored in
        I{fileName}.
        """
        header, dataset = xdp.io.readFile(fileName)
        spectra = cls(fileName, dataset.getMatrix())
        return spectra
    fromFile = classmethod(fromFile)
